# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class PackageDetailData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, account=None, slug=None, user=None, name=None, type=None):
        """
        PackageDetailData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'account': 'str',
            'slug': 'str',
            'user': 'str',
            'name': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'account': 'account',
            'slug': 'slug',
            'user': 'user',
            'name': 'name',
            'type': 'type'
        }

        self._account = account
        self._slug = slug
        self._user = user
        self._name = name
        self._type = type

    @property
    def account(self):
        """
        Gets the account of this PackageDetailData.
        account slug of package

        :return: The account of this PackageDetailData.
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """
        Sets the account of this PackageDetailData.
        account slug of package

        :param account: The account of this PackageDetailData.
        :type: str
        """

        self._account = account

    @property
    def slug(self):
        """
        Gets the slug of this PackageDetailData.
        slug of package

        :return: The slug of this PackageDetailData.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this PackageDetailData.
        slug of package

        :param slug: The slug of this PackageDetailData.
        :type: str
        """

        self._slug = slug

    @property
    def user(self):
        """
        Gets the user of this PackageDetailData.
        actual user of package

        :return: The user of this PackageDetailData.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this PackageDetailData.
        actual user of package

        :param user: The user of this PackageDetailData.
        :type: str
        """

        self._user = user

    @property
    def name(self):
        """
        Gets the name of this PackageDetailData.
        Fully qualified name, account_slug/slug of package

        :return: The name of this PackageDetailData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PackageDetailData.
        Fully qualified name, account_slug/slug of package

        :param name: The name of this PackageDetailData.
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this PackageDetailData.
        Either 'theme' or 'layout'

        :return: The type of this PackageDetailData.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this PackageDetailData.
        Either 'theme' or 'layout'

        :param type: The type of this PackageDetailData.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class ErrorResponse409(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, status_code=None, errors=None, purchase_packages_required=None, purchase_packages_given=None, auto_share_packages_required=None, auto_share_packages_given=None, redirect_url=None):
        """
        ErrorResponse409 - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status_code': 'int',
            'errors': 'list[str]',
            'purchase_packages_required': 'list[str]',
            'purchase_packages_given': 'list[str]',
            'auto_share_packages_required': 'list[str]',
            'auto_share_packages_given': 'list[str]',
            'redirect_url': 'str'
        }

        self.attribute_map = {
            'status_code': 'status_code',
            'errors': 'errors',
            'purchase_packages_required': 'purchase_packages_required',
            'purchase_packages_given': 'purchase_packages_given',
            'auto_share_packages_required': 'auto_share_packages_required',
            'auto_share_packages_given': 'auto_share_packages_given',
            'redirect_url': 'redirect_url'
        }

        self._status_code = status_code
        self._errors = errors
        self._purchase_packages_required = purchase_packages_required
        self._purchase_packages_given = purchase_packages_given
        self._auto_share_packages_required = auto_share_packages_required
        self._auto_share_packages_given = auto_share_packages_given
        self._redirect_url = redirect_url

    @property
    def status_code(self):
        """
        Gets the status_code of this ErrorResponse409.
        Error custom status code.

        :return: The status_code of this ErrorResponse409.
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """
        Sets the status_code of this ErrorResponse409.
        Error custom status code.

        :param status_code: The status_code of this ErrorResponse409.
        :type: int
        """

        self._status_code = status_code

    @property
    def errors(self):
        """
        Gets the errors of this ErrorResponse409.
        Validation error.

        :return: The errors of this ErrorResponse409.
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this ErrorResponse409.
        Validation error.

        :param errors: The errors of this ErrorResponse409.
        :type: list[str]
        """

        self._errors = errors

    @property
    def purchase_packages_required(self):
        """
        Gets the purchase_packages_required of this ErrorResponse409.
        Validation error.

        :return: The purchase_packages_required of this ErrorResponse409.
        :rtype: list[str]
        """
        return self._purchase_packages_required

    @purchase_packages_required.setter
    def purchase_packages_required(self, purchase_packages_required):
        """
        Sets the purchase_packages_required of this ErrorResponse409.
        Validation error.

        :param purchase_packages_required: The purchase_packages_required of this ErrorResponse409.
        :type: list[str]
        """

        self._purchase_packages_required = purchase_packages_required

    @property
    def purchase_packages_given(self):
        """
        Gets the purchase_packages_given of this ErrorResponse409.
        Validation error.

        :return: The purchase_packages_given of this ErrorResponse409.
        :rtype: list[str]
        """
        return self._purchase_packages_given

    @purchase_packages_given.setter
    def purchase_packages_given(self, purchase_packages_given):
        """
        Sets the purchase_packages_given of this ErrorResponse409.
        Validation error.

        :param purchase_packages_given: The purchase_packages_given of this ErrorResponse409.
        :type: list[str]
        """

        self._purchase_packages_given = purchase_packages_given

    @property
    def auto_share_packages_required(self):
        """
        Gets the auto_share_packages_required of this ErrorResponse409.
        Validation error.

        :return: The auto_share_packages_required of this ErrorResponse409.
        :rtype: list[str]
        """
        return self._auto_share_packages_required

    @auto_share_packages_required.setter
    def auto_share_packages_required(self, auto_share_packages_required):
        """
        Sets the auto_share_packages_required of this ErrorResponse409.
        Validation error.

        :param auto_share_packages_required: The auto_share_packages_required of this ErrorResponse409.
        :type: list[str]
        """

        self._auto_share_packages_required = auto_share_packages_required

    @property
    def auto_share_packages_given(self):
        """
        Gets the auto_share_packages_given of this ErrorResponse409.
        Validation error.

        :return: The auto_share_packages_given of this ErrorResponse409.
        :rtype: list[str]
        """
        return self._auto_share_packages_given

    @auto_share_packages_given.setter
    def auto_share_packages_given(self, auto_share_packages_given):
        """
        Sets the auto_share_packages_given of this ErrorResponse409.
        Validation error.

        :param auto_share_packages_given: The auto_share_packages_given of this ErrorResponse409.
        :type: list[str]
        """

        self._auto_share_packages_given = auto_share_packages_given

    @property
    def redirect_url(self):
        """
        Gets the redirect_url of this ErrorResponse409.
        url if redirection to website is needed at all.

        :return: The redirect_url of this ErrorResponse409.
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """
        Sets the redirect_url of this ErrorResponse409.
        url if redirection to website is needed at all.

        :param redirect_url: The redirect_url of this ErrorResponse409.
        :type: str
        """

        self._redirect_url = redirect_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class ErrorResponse412(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, status_code=None, error=None, message=None, items=None, data=None, thumbnail_image_data=None, redirect_url=None, validator_sets_to_pass=None):
        """
        ErrorResponse412 - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status_code': 'int',
            'error': 'list[FailedDependencyError]',
            'message': 'str',
            'items': 'str',
            'data': 'list[DependencyPackageDetail]',
            'thumbnail_image_data': 'list[object]',
            'redirect_url': 'str',
            'validator_sets_to_pass': 'list[ValidatorSetsInBadge]'
        }

        self.attribute_map = {
            'status_code': 'status_code',
            'error': 'error',
            'message': 'message',
            'items': 'items',
            'data': 'data',
            'thumbnail_image_data': 'thumbnail_image_data',
            'redirect_url': 'redirect_url',
            'validator_sets_to_pass': 'validator_sets_to_pass'
        }

        self._status_code = status_code
        self._error = error
        self._message = message
        self._items = items
        self._data = data
        self._thumbnail_image_data = thumbnail_image_data
        self._redirect_url = redirect_url
        self._validator_sets_to_pass = validator_sets_to_pass

    @property
    def status_code(self):
        """
        Gets the status_code of this ErrorResponse412.
        Error custom status code.

        :return: The status_code of this ErrorResponse412.
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """
        Sets the status_code of this ErrorResponse412.
        Error custom status code.

        :param status_code: The status_code of this ErrorResponse412.
        :type: int
        """

        self._status_code = status_code

    @property
    def error(self):
        """
        Gets the error of this ErrorResponse412.
        Validation error.

        :return: The error of this ErrorResponse412.
        :rtype: list[FailedDependencyError]
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this ErrorResponse412.
        Validation error.

        :param error: The error of this ErrorResponse412.
        :type: list[FailedDependencyError]
        """

        self._error = error

    @property
    def message(self):
        """
        Gets the message of this ErrorResponse412.
        error message.

        :return: The message of this ErrorResponse412.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ErrorResponse412.
        error message.

        :param message: The message of this ErrorResponse412.
        :type: str
        """

        self._message = message

    @property
    def items(self):
        """
        Gets the items of this ErrorResponse412.
        Validation error. List of private dependencies

        :return: The items of this ErrorResponse412.
        :rtype: str
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this ErrorResponse412.
        Validation error. List of private dependencies

        :param items: The items of this ErrorResponse412.
        :type: str
        """

        self._items = items

    @property
    def data(self):
        """
        Gets the data of this ErrorResponse412.
        Validation error. List of paid dependencies

        :return: The data of this ErrorResponse412.
        :rtype: list[DependencyPackageDetail]
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this ErrorResponse412.
        Validation error. List of paid dependencies

        :param data: The data of this ErrorResponse412.
        :type: list[DependencyPackageDetail]
        """

        self._data = data

    @property
    def thumbnail_image_data(self):
        """
        Gets the thumbnail_image_data of this ErrorResponse412.


        :return: The thumbnail_image_data of this ErrorResponse412.
        :rtype: list[object]
        """
        return self._thumbnail_image_data

    @thumbnail_image_data.setter
    def thumbnail_image_data(self, thumbnail_image_data):
        """
        Sets the thumbnail_image_data of this ErrorResponse412.


        :param thumbnail_image_data: The thumbnail_image_data of this ErrorResponse412.
        :type: list[object]
        """

        self._thumbnail_image_data = thumbnail_image_data

    @property
    def redirect_url(self):
        """
        Gets the redirect_url of this ErrorResponse412.
        url if redirection to website is needed at all.

        :return: The redirect_url of this ErrorResponse412.
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """
        Sets the redirect_url of this ErrorResponse412.
        url if redirection to website is needed at all.

        :param redirect_url: The redirect_url of this ErrorResponse412.
        :type: str
        """

        self._redirect_url = redirect_url

    @property
    def validator_sets_to_pass(self):
        """
        Gets the validator_sets_to_pass of this ErrorResponse412.
        Need to pass at least one complete set of validators

        :return: The validator_sets_to_pass of this ErrorResponse412.
        :rtype: list[ValidatorSetsInBadge]
        """
        return self._validator_sets_to_pass

    @validator_sets_to_pass.setter
    def validator_sets_to_pass(self, validator_sets_to_pass):
        """
        Sets the validator_sets_to_pass of this ErrorResponse412.
        Need to pass at least one complete set of validators

        :param validator_sets_to_pass: The validator_sets_to_pass of this ErrorResponse412.
        :type: list[ValidatorSetsInBadge]
        """

        self._validator_sets_to_pass = validator_sets_to_pass

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

import os.path
from os.path import relpath
import os
import re
from blendedUx.blended_flask.blended_hostlib.transform_image import TransformImage
from blendedUx.blended_flask.settings import *


def multiple_replace(replace_characters, text):
    """
    """
    pattern = "|".join(map(re.escape, replace_characters.keys()))
    return re.sub(pattern, lambda m: replace_characters[m.group()], text)


def save_css(path, content):
    """
    :param name:
    :param content:
    :return:
    """
    split_path = path.rsplit(os.sep, 1)
    if len(split_path) > 1:
        file_dir = split_path[0]
        file_name = split_path[1] + '.css'
        if not os.path.isdir(file_dir):
            os.makedirs(file_dir)
    path = os.path.join(file_dir, file_name)
    with open(path, 'w') as file_name:
        file_name.write(content)
    return path


def get_image_path(image_url, **kwargs):
    """
    Generate Cached Image.
    """
    replace_characters = {os.sep: '_', '.': '_'}
    filter_hash_char_replace = {'#': ''}
    filter_replace = {'series(': ''}
    height = kwargs.get('height', None)
    width = kwargs.get('width', None)
    filters = kwargs.get('filters', None)

    image_url = os.path.realpath(image_url)

    save_path = multiple_replace(replace_characters, image_url)

    file_extension = image_url.split('.')[-1].lower()

    if(height):
        save_path = '_'.join([save_path, str(height)])
    if(width):
        save_path = 'x'.join([save_path, str(width)])
    if(filters):
        save_path = '_'.join([save_path, str(filters)])
    if(file_extension):
        save_path = '.'.join([save_path, file_extension])

    save_path = multiple_replace(filter_hash_char_replace, save_path)
    save_path = os.path.join(IMAGE_CACHE_DIR, save_path)

    if(not os.path.exists(save_path)):
        obj = TransformImage(image_url, height, width)
        if(not filters):
            filters = 'series()'
        if(filters.startswith("series")):
            img_obj = obj.apply_filter(filters)
        else:
            # WHY this  TODO
            filters = multiple_replace(filter_replace, filters)
            # filters = filters.rstrip(")")
            img_obj = obj.apply_filter(filters)
            # img_obj = obj._do_series(filters)
        if file_extension:
            file_extension = file_extension.upper()
            if(file_extension == 'BMP'):
                extension = file_extension
            elif(file_extension == 'PNG'):
                extension = file_extension
            elif(file_extension == 'GIF'):
                extension = file_extension
            else:
                extension = 'JPEG'
            img_obj.image.save(save_path, extension, quality=100,
                               optimize=True, progressive=True)
    return save_path

from flask import send_file
def get_css(css_file_path):
    def css_path(f):
        def decorator1(*args, **kwargs):
            path = kwargs['path']
            file_path = os.path.join(css_file_path, path)
            return send_file(file_path)
        return decorator1
    return css_path


def get_js(js_file_path):
    def js_path(f):
        def decorator2(*args, **kwargs):
            path = kwargs['path']
            file_path = os.path.join(js_file_path, path)
            return send_file(file_path)
        return decorator2
    return js_path


def get_media(media_file_path):
    def media_path(f):
        def decorator3(*args, **kwargs):
            path = kwargs['path']
            file_path = os.path.join(media_file_path, path)
            return send_file(file_path)
        return decorator3
    return media_path



from unittest import TestCase
from time import sleep

import os
import unittest
import json
import string
import random
import re
import shutil

from blendedcli.helpers import *
from blendedUx.blended_flask.blended_hostlib.backend import FileSystemBackend
from blendedUx.blended_flask.blended_hostlib.network import Network
from blendedUx.blended_flask.blended_hostlib.controller import Controller
from blendedUx.blended_flask.blended_hostlib.exceptions import BlendedException, \
    PackageNameExistsException, AccountActivationException


blended_dir = get_blended_directory_path()
current_account = "sun72"
current_dir = os.path.join(blended_dir, current_account)
network = Network()
backend = FileSystemBackend(
                            current_dir, blended_dir=blended_dir,
                            current_account=current_account,
                            blended_directory_path=blended_dir)
controller = Controller(network, backend)



class NetworkTest(TestCase):
    """
    We are testing hub using hostlib_Network
    """
    def test_00_backend_intermediary(self):
        """
        get version from backend and save data on backend
        """
        try:
            package_obj = controller.get_package(package_name="sun72/business_theme", format='context', version="1.0")
        except OSError:
            package_obj = {} 
        self.assertIsInstance(package_obj, dict)

    def test_01_backend_intermediary(self):
        """
        get draft with dependencyies.
        """
        package_obj = controller.get_package(package_name="sun72/business_theme", format='context', version="draft")
        self.assertIsInstance(package_obj, dict)

    def test_02_backend_intermediary(self):
        """
        get version from backend and save data on backend
        """
        package_obj = controller.get_package(package_name="sun72/business_theme", format='context', version="1.0", dependency=True )
        self.assertIsInstance(package_obj, dict)

    def test_03_backend_intermediary_invalid_package(self):
        """
        get version from backend and save data on backend
        """
        try:
            package_obj = controller.get_package(package_name="sun72/business_theme_invalid", format='context', version="1.0", dependency=True )
        except BlendedException as exc:
            self.assertEqual(exc.args[0].args[0], {'status_code': 5008, 'message': 'Package does not exist.'})

    def test_04_backend_intermediary_invalid_version(self):
        """
        get version from backend and save data on backend
        """
        try:
            package_obj = controller.get_package(package_name="sun72/business_theme", format='context', version="1.45", dependency=True )
        except BlendedException as exc:
            self.assertEqual(exc.args[0].args[0], {'message': 'Version does not exist', 'status_code': 9999})

    def test_05_backend_intermediary(self):
        """
        get version from backend and save data on backend
        """
        package_obj = controller.get_package(package_name="sun72/business_theme", format='context', version="1.0")
        self.assertIsInstance(package_obj, dict)
        
if __name__ == '__main__':
    unittest.main()





# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class HyperLinkCurrentAccount(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, href=None, slug=None, name=None, role=None, admins=None, users=None, pendings=None):
        """
        HyperLinkCurrentAccount - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'href': 'str',
            'slug': 'str',
            'name': 'str',
            'role': 'str',
            'admins': 'object',
            'users': 'object',
            'pendings': 'object'
        }

        self.attribute_map = {
            'href': 'href',
            'slug': 'slug',
            'name': 'name',
            'role': 'role',
            'admins': 'admins',
            'users': 'users',
            'pendings': 'pendings'
        }

        self._href = href
        self._slug = slug
        self._name = name
        self._role = role
        self._admins = admins
        self._users = users
        self._pendings = pendings

    @property
    def href(self):
        """
        Gets the href of this HyperLinkCurrentAccount.
        current object reference url

        :return: The href of this HyperLinkCurrentAccount.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this HyperLinkCurrentAccount.
        current object reference url

        :param href: The href of this HyperLinkCurrentAccount.
        :type: str
        """

        self._href = href

    @property
    def slug(self):
        """
        Gets the slug of this HyperLinkCurrentAccount.
        unique value used for account.

        :return: The slug of this HyperLinkCurrentAccount.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this HyperLinkCurrentAccount.
        unique value used for account.

        :param slug: The slug of this HyperLinkCurrentAccount.
        :type: str
        """

        self._slug = slug

    @property
    def name(self):
        """
        Gets the name of this HyperLinkCurrentAccount.
        name of the account.

        :return: The name of this HyperLinkCurrentAccount.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HyperLinkCurrentAccount.
        name of the account.

        :param name: The name of this HyperLinkCurrentAccount.
        :type: str
        """

        self._name = name

    @property
    def role(self):
        """
        Gets the role of this HyperLinkCurrentAccount.
        user's role in this account.

        :return: The role of this HyperLinkCurrentAccount.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this HyperLinkCurrentAccount.
        user's role in this account.

        :param role: The role of this HyperLinkCurrentAccount.
        :type: str
        """

        self._role = role

    @property
    def admins(self):
        """
        Gets the admins of this HyperLinkCurrentAccount.
        account admin users details.

        :return: The admins of this HyperLinkCurrentAccount.
        :rtype: object
        """
        return self._admins

    @admins.setter
    def admins(self, admins):
        """
        Sets the admins of this HyperLinkCurrentAccount.
        account admin users details.

        :param admins: The admins of this HyperLinkCurrentAccount.
        :type: object
        """

        self._admins = admins

    @property
    def users(self):
        """
        Gets the users of this HyperLinkCurrentAccount.
        account regular users details.

        :return: The users of this HyperLinkCurrentAccount.
        :rtype: object
        """
        return self._users

    @users.setter
    def users(self, users):
        """
        Sets the users of this HyperLinkCurrentAccount.
        account regular users details.

        :param users: The users of this HyperLinkCurrentAccount.
        :type: object
        """

        self._users = users

    @property
    def pendings(self):
        """
        Gets the pendings of this HyperLinkCurrentAccount.
        account pendings users details

        :return: The pendings of this HyperLinkCurrentAccount.
        :rtype: object
        """
        return self._pendings

    @pendings.setter
    def pendings(self, pendings):
        """
        Sets the pendings of this HyperLinkCurrentAccount.
        account pendings users details

        :param pendings: The pendings of this HyperLinkCurrentAccount.
        :type: object
        """

        self._pendings = pendings

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
